@@ -17,7 +17,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(finddeps);
 
-$VERSION = '2.4';
+$VERSION = '2.41';
 
 use constant DEFAULT02PACKAGES => 'http://www.cpan.org/modules/02packages.details.txt.gz';
 use constant MAXINT => ~0;
@@ -205,6 +205,8 @@ Ian Tegebo (for the code to extract deps from Makefile.PL)
 
 Georg Oechsler (for the code to also list 'recommended' modules)
 
+Jonathan Stowe (for making it work through HTTP proxies)
+
 =head1 CONSPIRACY
 
 This module is also free-as-in-mason software.
@@ -278,6 +280,7 @@ sub _get02packages {
 sub _get {
     my $url = shift;
     my $ua = LWP::UserAgent->new();
+    $ua->env_proxy();
     $ua->agent(__PACKAGE__."/$VERSION");
     my $response = $ua->get($url);
     if($response->is_success()) {
